<!--
SPDX-FileCopyrightText: 2017-2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->
# Committers
For a current overview of committers to this project, please look [here](https://github.com/OpenSTEF/openstef/graphs/contributors).

The project does not distinguish in owners / committers / emeritus committers (yet).
